@@ -73,10 +73,10 @@ class PartnersClient(AbstractClient):
 
 
     def AssignClientsToSales(self, request):
-        """为代客or申请中代客分派跟进人（业务员）
+        """为代客or申请中代客分派跟进人（业务员），入参可从以下API获取
         - 代客列表获取API： [DescribeAgentAuditedClients](https://cloud.tencent.com/document/product/563/19184)
         - 申请中代客列表获取API：[DescribeAgentClients](https://cloud.tencent.com/document/product/563/16046)
-        - 业务员列表获取API：[DescribeSalesmans](https://cloud.tencent.com/document/product/563/35196)
+        - 业务员列表获取API：[DescribeSalesmans](https://cloud.tencent.com/document/product/563/35196) <br><br>
 
         :param request: Request instance for AssignClientsToSales.
         :type request: :class:`tencentcloud.partners.v20180321.models.AssignClientsToSalesRequest`
@@ -375,7 +375,9 @@ class PartnersClient(AbstractClient):
 
 
     def DescribeClientBalance(self, request):
-        """【该接口将逐步下线，请切换使用升级版本DescribeClientBalanceNew】为合作伙伴提供查询客户余额能力。调用者必须是合作伙伴，只能查询自己名下客户余额.
+        """已提供新接口并推进切换，白名单禁用控制访问观察后无反馈，可以下线
+
+        【该接口将逐步下线，请切换使用升级版本DescribeClientBalanceNew】为合作伙伴提供查询客户余额能力。调用者必须是合作伙伴，只能查询自己名下客户余额.
 
         :param request: Request instance for DescribeClientBalance.
         :type request: :class:`tencentcloud.partners.v20180321.models.DescribeClientBalanceRequest`
